==> dbt-postgres-0.19.0rc3.tar.gz: dbt-postgres-0.19.0rc3/README.md <==
<p align="center">
  <img src="/etc/dbt-logo-full.svg" alt="dbt logo" width="500"/>
</p>

**[dbt](https://www.getdbt.com/)** (data build tool) enables data analysts and engineers to transform their data using the same practices that software engineers use to build applications.

dbt is the T in ELT. Organize, cleanse, denormalize, filter, rename, and pre-aggregate the raw data in your warehouse so that it's ready for analysis.

## dbt-postgres

The `dbt-postgres` package contains all of the code required to make dbt operate on a Postgres database. For
more information on using dbt with Postgres, consult [the docs](https://docs.getdbt.com/docs/profile-postgres).


## Find out more

-   Check out the [Introduction to dbt](https://dbt.readme.io/docs/introduction).
-   Read the [dbt Viewpoint](https://dbt.readme.io/docs/viewpoint).

## Join thousands of analysts in the dbt community

-   Join the [chat](http://community.getdbt.com/) on Slack.
-   Find community posts on [dbt Discourse](https://discourse.getdbt.com).

## Reporting bugs and contributing code

-   Want to report a bug or request a feature? Let us know on [Slack](http://community.getdbt.com/), or open [an issue](https://github.com/fishtown-analytics/dbt/issues/new).
-   Want to help us build dbt? Check out the [Contributing Getting Started Guide](/CONTRIBUTING.md)

## Code of Conduct

Everyone interacting in the dbt project's codebases, issue trackers, chat rooms, and mailing lists is expected to follow the [PyPA Code of Conduct](https://www.pypa.io/en/latest/code-of-conduct/).

==> dbt-postgres-0.20.2rc2.tar.gz: dbt-postgres-0.20.2rc2/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/fishtown-analytics/dbt/6c6649f9129d5d108aa3b0526f634cd8f3a9d1ed/etc/dbt-logo-full.svg" alt="dbt logo" width="500"/>
</p>

**[dbt](https://www.getdbt.com/)** (data build tool) enables data analysts and engineers to transform their data using the same practices that software engineers use to build applications.

dbt is the T in ELT. Organize, cleanse, denormalize, filter, rename, and pre-aggregate the raw data in your warehouse so that it's ready for analysis.

## dbt-postgres

The `dbt-postgres` package contains all of the code required to make dbt operate on a Postgres database. For
more information on using dbt with Postgres, consult [the docs](https://docs.getdbt.com/docs/profile-postgres).


## Find out more

-   Check out the [Introduction to dbt](https://docs.getdbt.com/docs/introduction/).
-   Read the [dbt Viewpoint](https://docs.getdbt.com/docs/about/viewpoint/).

## Join thousands of analysts in the dbt community

-   Join the [chat](http://community.getdbt.com/) on Slack.
-   Find community posts on [dbt Discourse](https://discourse.getdbt.com).

## Reporting bugs and contributing code

-   Want to report a bug or request a feature? Let us know on [Slack](http://community.getdbt.com/), or open [an issue](https://github.com/fishtown-analytics/dbt/issues/new).
-   Want to help us build dbt? Check out the [Contributing Getting Started Guide](https://github.com/fishtown-analytics/dbt/blob/HEAD/CONTRIBUTING.md)

## Code of Conduct

Everyone interacting in the dbt project's codebases, issue trackers, chat rooms, and mailing lists is expected to follow the [dbt Code of Conduct](https://community.getdbt.com/code-of-conduct).
